@@ -1,9 +1,12 @@
-/// module containig enums to represent different console actions for linux
+/// module containig different console actions for linux
 pub mod console {
     /// enum for display control
     pub enum DisplayControl {
+        /// clear the display (doesnt move cursor)
         Clear,
+        /// clear the current line the cursor is on (doesn't move the cursor)
         ClearLine,
+        /// reset the display
         Reset,
     }
 
@@ -30,11 +33,10 @@ pub mod console {
         let seq: String = match sequence {
             DisplayControl::Clear => String::from("\x1b[2J"),
             DisplayControl::ClearLine => String::from("\x1b[2K"),
-            DisplayControl::Reset => String::from("\x1bc")
+            DisplayControl::Reset => String::from("\x1bc"),
         };
 
         print!("{}", seq);
-
     }
     /// function to perform an action for cursor controlling (using a `CursorControl` enum)
     /// # Arguments
